@@ -3,6 +3,7 @@ module Graphics.Gloss.Internals.Interface.Display
         (displayWithBackend)
 where   
 import Graphics.Gloss.Data.Color
+import Graphics.Gloss.Data.Controller
 import Graphics.Gloss.Data.Picture
 import Graphics.Gloss.Data.ViewPort
 import Graphics.Gloss.Data.ViewState
@@ -20,22 +21,27 @@ import System.Mem
 
 displayWithBackend
         :: Backend a
-        => a                -- ^ Initial state of the backend.
-        -> Display          -- ^ Display config.
-        -> Color            -- ^ Background color.
-        -> Picture          -- ^ The picture to draw.
+        => a                            -- ^ Initial state of the backend.
+        -> Display                      -- ^ Display config.
+        -> Color                        -- ^ Background color.
+        -> IO Picture                   -- ^ Make the picture to draw.
+        -> (Controller -> IO ())        -- ^ Eat the controller
         -> IO ()
 
-displayWithBackend backend displayMode background picture
- =  do  viewSR          <- newIORef viewStateInit
+displayWithBackend
+        backend displayMode background
+        makePicture
+        eatController
 
+ =  do  viewSR          <- newIORef viewStateInit
         renderS         <- initState
         renderSR        <- newIORef renderS
         
         let renderFun backendRef = do
-                port      <- viewStateViewPort <$> readIORef viewSR
-                options   <- readIORef renderSR
+                port       <- viewStateViewPort <$> readIORef viewSR
+                options    <- readIORef renderSR
                 windowSize <- getWindowDimensions backendRef
+                picture    <- makePicture
 
                 displayPicture 
                         windowSize
@@ -58,4 +64,23 @@ displayWithBackend backend displayMode background picture
                 , callback_viewState_motion   viewSR
                 , callback_viewState_reshape ]
 
+        -- When we create the window we can pass a function to get a
+        -- reference to the backend state. Using this we make a controller
+        -- so the client can control the window asynchronously.
         createWindow backend displayMode background callbacks
+         $ \  backendRef
+           -> eatController
+                $ Controller
+                { controllerSetRedraw
+                   = do postRedisplay backendRef
+
+                , controllerModifyViewPort 
+                   = \modViewPort
+                     -> do viewState       <- readIORef viewSR
+                           port'           <- modViewPort $ viewStateViewPort viewState
+                           let viewState'  =  viewState { viewStateViewPort = port' }
+                           writeIORef viewSR viewState'
+                           postRedisplay backendRef
+                }
+
+
